//+------------------------------------------------------------------+
//|                                          WeeklyOpenHistogram.mq4 |
//|                      Copyright  2012, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
#property copyright "Copyright  2012, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net"

#property  indicator_separate_window
#property  indicator_buffers 3
#property  indicator_color1  LimeGreen
#property  indicator_color2  FireBrick 
#property  indicator_color3  Yellow

//---- indicator parameters
extern int BarsToProcess = 1000;

//---- indicator buffers
double UpBuffer[];
double DownBuffer[];
double ZeroBuffer[];

//---- global variables
datetime current_time;
int      i;
int      line_thickness;
int      pivot_bar;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
    //---- Indicators

    //---- 2 additional buffers are used for counting.
    IndicatorBuffers(3);
    //---- drawing settings
    SetIndexStyle(0,DRAW_HISTOGRAM,STYLE_SOLID,4);
    SetIndexStyle(1,DRAW_HISTOGRAM,STYLE_SOLID,4);
    SetIndexStyle(2,DRAW_HISTOGRAM,STYLE_SOLID,4);

    IndicatorDigits(MarketInfo(Symbol(),MODE_DIGITS)+2);

    //---- 3 indicator buffers mapping
    if(!SetIndexBuffer(0,UpBuffer) &&
       !SetIndexBuffer(1,DownBuffer) &&
       !SetIndexBuffer(2,ZeroBuffer))
       Print("cannot set indicator buffers!");
    //---- name for DataWindow and indicator subwindow label
    IndicatorShortName("WeeklyOpen");
    //---- initialization done
    return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
    //----
   
    //----
    return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
    //----
    double wo, ma;
    int nLimit, i;
    int nCountedBars;
         
    nCountedBars = IndicatorCounted();
    //---- check for possible errors
    if(nCountedBars<0) return(-1);
    //---- last counted bar will be recounted
    if(nCountedBars>0) nCountedBars--;
    nLimit = Bars-nCountedBars;
    if(nLimit>BarsToProcess) nLimit=BarsToProcess;
    //---- main loop
    for(i=0; i<nLimit; i++)
      {
        DownBuffer[i] = 0.0;
        UpBuffer[i]   = 0.0;
        ZeroBuffer[i] = 0.0;
      
        current_time = Time[i];
        // and seach the corresponding bar in the pivot timeframe
        pivot_bar = iBarShift( NULL, PERIOD_W1, current_time);
        // read the values of that previous week/month
        wo = iOpen(NULL, PERIOD_W1, pivot_bar+1);
        ma = iMA(NULL,0,2,1,MODE_LWMA,PRICE_MEDIAN,i);

        if(ma > wo) UpBuffer[i]   = NormalizeDouble(ma-wo,Digits);
        if(wo > ma) DownBuffer[i] = NormalizeDouble(ma-wo,Digits);
      }
    //----
    return(0);
  }

//+------------------------------------------------------------------+